package cn.com.qmth.examcloud.core.basic.service.cache;

import cn.com.qmth.examcloud.core.basic.base.util.PhotoPathHelper;
import cn.com.qmth.examcloud.core.basic.dao.StudentCodeRepo;
import cn.com.qmth.examcloud.core.basic.dao.StudentRepo;
import cn.com.qmth.examcloud.core.basic.dao.entity.StudentCodeEntity;
import cn.com.qmth.examcloud.core.basic.dao.entity.StudentEntity;
import cn.com.qmth.examcloud.support.CacheConstants;
import cn.com.qmth.examcloud.support.cache.bean.StudentCacheBean;
import cn.com.qmth.examcloud.support.fss.FssHelper;
import cn.com.qmth.examcloud.web.cache.RandomObjectRedisCache;
import cn.com.qmth.examcloud.web.helpers.GlobalHelper;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class StudentCache extends RandomObjectRedisCache<StudentCacheBean> {

    @Autowired
    StudentRepo studentRepo;

    @Autowired
    StudentCodeRepo studentCodeRepo;

    // @Autowired
    // StudentFaceRepo studentFaceRepo;

    @Override
    public StudentCacheBean loadFromResource(Object... keys) {
        Long studentId = (Long) keys[0];
        StudentEntity s = GlobalHelper.getPresentEntity(studentRepo, studentId, StudentEntity.class);

        StudentCacheBean b = new StudentCacheBean();
        b.setId(s.getId());
        b.setEnable(s.getEnable());
        b.setIdentityNumber(s.getIdentityNumber());
        b.setName(s.getName());
        b.setOrgId(s.getOrgId());
        b.setPhoneNumber(s.getPhoneNumber());
        b.setRemark(s.getRemark());
        b.setRootOrgId(s.getRootOrgId());
        b.setSecurityPhone(s.getSecurityPhone());

        if (StringUtils.isNotBlank(s.getPhotoPath())) {
            String photoPath = PhotoPathHelper.fixPhotoPath(s.getPhotoPath());
            b.setPhotoPath(FssHelper.finalFileUrl(photoPath));
        }

        List<StudentCodeEntity> studentCodeEntityList = studentCodeRepo.findByStudentId(s.getId());
        List<String> studentCodeList = Lists.newArrayList();
        for (StudentCodeEntity cur : studentCodeEntityList) {
            studentCodeList.add(cur.getStudentCode());
        }
        b.setStudentCodeList(studentCodeList);

        // StudentFaceEntity studentFaceEntity = GlobalHelper.getEntity(studentFaceRepo, studentId, StudentFaceEntity.class);
        // if (null != studentFaceEntity) {
        //     b.setFaceToken(studentFaceEntity.getFaceToken());
        // }

        return b;
    }

    @Override
    protected String getKeyPrefix() {
        return CacheConstants.CACHE_B_STUDENT;
    }

    @Override
    protected int getTimeout() {
        // 120分钟
        return 60 * 120;
    }

}
